CheckoutSettings class
Constructors
- CheckoutSettings({bool? useBrandLogo, dynamic buttonTextColor, dynamic buttonColor, dynamic fontColor, dynamic fontFamily, dynamic backgroundColor, dynamic backgroundTextColor})
- CheckoutSettings.fromJson(String str)
-
factory
-
CheckoutSettings.fromMap(Map<
String, dynamic> json) -
factory
Properties
- backgroundColor → dynamic
-
final
- backgroundTextColor → dynamic
-
final
-
final
-
final
- fontColor → dynamic
-
final
- fontFamily → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useBrandLogo → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited